@@ -356,16 +356,16 @@ void MaemoBarcodeWindow::ensurePluginsLoaded()
 //    startScan();
 //}
 
-void MaemoBarcodeWindow::on_btnCancel_clicked()
-{
-    this->videoWidget->stopTimedScan();
-    videoWidget->stop(true);
-}
+//void MaemoBarcodeWindow::on_btnCancel_clicked()
+//{
+//    this->videoWidget->stopTimedScan();
+//    videoWidget->stop(true);
+//}
 
-void MaemoBarcodeWindow::on_btnRefocus_clicked()
-{
-    videoWidget->refocus();
-}
+//void MaemoBarcodeWindow::on_btnRefocus_clicked()
+//{
+//    videoWidget->refocus();
+//}
 
 void MaemoBarcodeWindow::dataAnalysed(QString datatype, QString barcodeData, QHash<QString, QString> data) {
     // this is a slot for all data which may come from other plugins
@@ -425,8 +425,10 @@ void MaemoBarcodeWindow::showSettingsWindow()
     settingsWindow->show();
 }
 
-void MaemoBarcodeWindow::on_btnOpenImage_clicked()
+void MaemoBarcodeWindow::OpenAndScanImage()
 {
+    return;
+
     QString fileName = QFileDialog::getOpenFileName(this, tr("Open Image"), "/home/user/MyDocs/.images/", tr("Image Files (*.png *.jpg *.bmp *.gif *.tif*)"));
 
     // check this exists
@@ -434,6 +436,30 @@ void MaemoBarcodeWindow::on_btnOpenImage_clicked()
     if(!qfi.exists())
         return;
 
+    QImage img(qfi.absoluteFilePath());
+
+    // convert to an appropriate format
+    img = img.convertToFormat(QImage::Format_RGB888);
+
+    char fourcc[5] = "RGB3";
+    int bpp = 24;
+
+    // check the frame size, we might need to change the value of the globals
+    // to reflect this
+
+    int old_height = decoder->frame_height;
+    int old_width = decoder->frame_width;
+
+    decoder->frame_height = img.height();
+    decoder->frame_width = img.width();
+
+    decoder->scanning_status=true;
+    int type = decoder->analyseImage((char *)img.constBits(), fourcc, bpp);
+    decoder->scanning_status=false;
+
+    decoder->frame_height = old_height;
+    decoder->frame_width = old_width;
+
     //videoWidget->useFilesrc(fileName);
     //videoWidget->start();
 
@@ -441,23 +467,23 @@ void MaemoBarcodeWindow::on_btnOpenImage_clicked()
 
 }
 
-void MaemoBarcodeWindow::on_actionPlugins_triggered()
-{
-    videoWidget->stop(false);
-    PluginSettings* win = new PluginSettings(pluginInterfaces, this);
-    win->show();
-}
+//void MaemoBarcodeWindow::on_actionPlugins_triggered()
+//{
+//    videoWidget->stop(false);
+//    PluginSettings* win = new PluginSettings(pluginInterfaces, this);
+//    win->show();
+//}
 
-void MaemoBarcodeWindow::on_actionTest_portrait_mode_triggered()
-{
-    if(settings->value("portrait_mode", false).toBool()) {
-        setAttribute(Qt::WA_Maemo5LandscapeOrientation, true);
-        settings->setValue("portrait_mode", false);
-    } else {
-        setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
-        settings->setValue("portrait_mode", true);
-    }
-}
+//void MaemoBarcodeWindow::on_actionTest_portrait_mode_triggered()
+//{
+//    if(settings->value("portrait_mode", false).toBool()) {
+//        setAttribute(Qt::WA_Maemo5LandscapeOrientation, true);
+//        settings->setValue("portrait_mode", false);
+//    } else {
+//        setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
+//        settings->setValue("portrait_mode", true);
+//    }
+//}
 
 void MaemoBarcodeWindow::saveBufferImage()
 {
