@@ -3,6 +3,8 @@
 #include "maemobarcodewindow.h"
 #include "videowidget.h"
 #include "barcodedetector.h"
+#include "pluginsettings.h"
+#include "plugininterfaces.h"
 #include <QDebug>
 
 SettingsWindow::SettingsWindow(MaemoBarcodeWindow *parent) :
@@ -26,6 +28,7 @@ void SettingsWindow::hideEvent(QHideEvent *) {
     settings->setValue("use_full_screen", ui->chkFullScreen->isChecked());
     settings->setValue("autofocus_delay", ui->spnAutoFocusDelay->value());
     settings->setValue("continous_scanning", ui->radioButtonContinuousScanning->isChecked());
+    settings->setValue("auto_use_first_plugin", ui->chkUseFirstPlugin->isChecked());
     if(ui->chkFullScreen->isChecked()) {
         parent->showFullScreen();
     } else {
@@ -45,6 +48,12 @@ void SettingsWindow::hideEvent(QHideEvent *) {
         parent->videoWidget->setContinuousScanning(false);
     }
 
+    if (ui->chkUseFirstPlugin->isChecked()){
+        parent->AutoUseFirstPlugin = true;
+    }else{
+        parent->AutoUseFirstPlugin = false;
+    }
+
 //    settings->sync(); // Not necessary to call, it is called automatically.
 }
 
@@ -56,6 +65,7 @@ void SettingsWindow::showEvent(QShowEvent *) {
     ui->spnAutoFocusDelay->setValue(settings->value("autofocus_delay", 2.0).toDouble());
     ui->radioButtonContinuousScanning->setChecked(settings->value("continous_scanning", CONTINUOUS_SCANNING_DEFAULT).toBool());
     ui->radioButtonPressToScan->setChecked(!settings->value("continous_scanning", CONTINUOUS_SCANNING_DEFAULT).toBool());
+    ui->chkUseFirstPlugin->setChecked(settings->value("auto_use_first_plugin", false).toBool());
 }
 
 void SettingsWindow::changeEvent(QEvent *e)
@@ -90,3 +100,11 @@ void SettingsWindow::on_radioButtonPressToScan_clicked()
 {
     //ui->radioButtonContinuousScanning->setChecked(false);
 }
+
+
+
+void SettingsWindow::on_btnPluginSettings_clicked()
+{
+    PluginSettings* win = new PluginSettings(parent->pluginInterfaces, this);
+    win->show();
+}
