@@ -145,7 +145,7 @@ private:
 
     // openGL painting
     int frames;
-    QTime frametime;
+    //QTime frametime;
     QTimer *timerOpenGL;
     GLuint m_uiTexture;
     QGLShaderProgram *program2;
